// draw a colourful koch tetraeder

ruleset (
   T => {F+F+F};
)

define angle deg(acos(1/3));

tet_koch(n) => attr (delta, 120)
               +[\(angle)T]f
               +[\(angle)T]f
               +[\(angle)T]f
               ,n-1;

T => [{attr(distance,distance*0.5)
      attr(color,'1 0 0) F[+(60)\(angle)T]F+
      attr(color,'0 1 0) F[+(60)\(angle)T]F+
      attr(color,'0 0 1) F[+(60)\(angle)T]F
     }];

