#
# draw a simple inflorescense
#
# petal (degrees, count, edge, bow)
#
# degrees	degrees of each petal against the "up" vector.
# count		number of petals
# edge		see simple_leaf
# bow		see simple_leaf
#
#

include (simple_leaf)

petal(d,n)	=> petal (d,n,8,25,0), 1;
petal(d,n,e,b)	=> petal (d,n,e,b,0), 1;
petal(d,n,e,b,a)=> [&(90) attr (delta, 360/n) leaf(d,e,b,a)], n;
leaf(d,e,b,a)	=> [/(a) ^(d) simple_leaf (e, b)] + leaf(d,e,b,a);

