define factor 0.636619769/4;

disc(r)			=> disc(r,25),1;
disc(r,n)		=> [attr (delta, 360/n) attr (distance, r/(n*factor))
			    f(r) +(90) +(180/n) {segment (n)}], n;
segment(1)		=> F;
segment(n)		=> F+segment(n-1);
