seed(n)		=> circle(n*10) simple_tree(n) ,1;

circle(n)		=> segment (n, 360/n), n+1;
segment(n,d)	: n	=> F+(d)segment(n-1,d);
segment(0,d)		=> ;

simple_tree(n)		=> attr (delta, 30) attr (width, 5) attr (distance, 40) tree, n+5;
tree			=> F attr (width, width*0.6) attr (distance, distance*0.7) [-tree][+tree];
